@@ -9,6 +9,7 @@ __all__ = [
     'run_processor'
 ]
 
+from pkg_resources import resource_filename
 from os.path import exists
 from shutil import copyfileobj
 import json
@@ -22,6 +23,7 @@ import io
 from ocrd_utils import (
     VERSION as OCRD_VERSION,
     MIMETYPE_PAGE,
+    MIME_TO_EXT,
     getLogger,
     initLogging,
     list_resource_candidates,
@@ -94,40 +96,33 @@ class Processor():
              dump_json (boolean): If true, then instead of processing, print :py:attr:`ocrd_tool` \
                  on stdout.
         """
+        self.ocrd_tool = ocrd_tool
         if parameter is None:
             parameter = {}
         if dump_json:
             print(json.dumps(ocrd_tool, indent=True))
             return
         if list_resources:
-            has_dirs, has_files = get_processor_resource_types(None, ocrd_tool)
-            for res in list_all_resources(ocrd_tool['executable']):
-                if Path(res).is_dir() and not has_dirs:
-                    continue
-                if not Path(res).is_dir() and not has_files:
-                    continue
+            for res in self.list_all_resources():
                 print(res)
             return
         if show_resource:
-            has_dirs, has_files = get_processor_resource_types(None, ocrd_tool)
-            res_fname = list_resource_candidates(ocrd_tool['executable'], show_resource)
-            if not res_fname:
-                initLogging()
-                logger = getLogger('ocrd.%s.__init__' % ocrd_tool['executable'])
-                logger.error("Failed to resolve %s for processor %s" % (show_resource, ocrd_tool['executable']))
+            print(fpath)
+            initLogging()
+            res_fname = self.resolve_resource(show_resource)
+            fpath = Path(res_fname)
+            if fpath.is_dir():
+                with pushd_popd(fpath):
+                    fileobj = io.BytesIO()
+                    with tarfile.open(fileobj=fileobj, mode='w:gz') as tarball:
+                        tarball.add('.')
+                    fileobj.seek(0)
+                    copyfileobj(fileobj, sys.stdout.buffer)
             else:
-                fpath = Path(res_fname[0])
-                if fpath.is_dir():
-                    with pushd_popd(fpath):
-                        fileobj = io.BytesIO()
-                        with tarfile.open(fileobj=fileobj, mode='w:gz') as tarball:
-                            tarball.add('.')
-                        fileobj.seek(0)
-                        copyfileobj(fileobj, sys.stdout.buffer)
-                else:
-                    sys.stdout.buffer.write(fpath.read_bytes())
+                sys.stdout.buffer.write(fpath.read_bytes())
+                foo / 0
+                sys.stdout.xxxxflush()
             return
-        self.ocrd_tool = ocrd_tool
         if show_help:
             self.show_help()
             return
@@ -213,19 +208,50 @@ class Processor():
         if exists(val):
             log.debug("Resolved to absolute path %s" % val)
             return val
-        ret = [cand for cand in list_resource_candidates(executable, val, cwd=self.old_pwd) if exists(cand)]
+        if hasattr(self, 'old_pwd'):
+            cwd = self.old_pwd
+        else:
+            cwd = getcwd()
+        ret = [cand for cand in list_resource_candidates(executable, val,
+                                                         cwd=cwd, moduled=self.moduledir)
+               if exists(cand)]
         if ret:
             log.debug("Resolved %s to absolute path %s" % (val, ret[0]))
             return ret[0]
-        log.error("Could not find resource '%s' for executable '%s'. Try 'ocrd resmgr download %s %s' to download this resource.",
-                val, executable, executable, val)
+        log.error("Could not find resource '%s' for executable '%s'. "
+                  "Try 'ocrd resmgr download %s %s' to download this resource.",
+                  val, executable, executable, val)
         sys.exit(1)
 
     def list_all_resources(self):
         """
-        List all resources found in the filesystem
+        List all resources found in the filesystem and matching content-type by filename suffix
         """
-        return list_all_resources(self.ocrd_tool['executable'])
+        mimetypes = get_processor_resource_types(None, self.ocrd_tool)
+        for res in list_all_resources(self.ocrd_tool['executable'], moduled=self.moduledir):
+            res = Path(res)
+            if not '*/*' in mimetypes:
+                if res.is_dir() and not 'text/directory' in mimetypes:
+                    continue
+                # if we do not know all MIME types, then keep the file, otherwise require suffix match
+                if res.is_file() and not any(res.suffix == MIME_TO_EXT.get(mime, res.suffix)
+                                             for mime in mimetypes):
+                    continue
+            yield res
+
+    @property
+    def module(self):
+        """
+        The top-level module this processor belongs to.
+        """
+        return self.__module__.split('.')[0]
+
+    @property
+    def moduledir(self):
+        """
+        The filesystem path of the module directory.
+        """
+        return resource_filename(self.module, '')
 
     @property
     def input_files(self):
